==> funki-0.0.115.tar.gz: funki-0.0.115/funki/test.py <==
from funki.refactor_recommender import RefactorRecommender
import importlib
from os.path import exists
from pickle import load
from os import listdir

def print_header(max_filename_length):
  name = "Name"
  duration_ms = "Duration [ms]"
  example_max_duration = "1024.567 █████████████████████"
  
  result ='\n'.join([
    f"| Result | {name:{max_filename_length}} | {duration_ms:^{len(example_max_duration)}}| ",
    f"|--------|-" + "-"*max_filename_length +"-|-" + "-"*len(example_max_duration)+"|"  
  ])
  print(result)

def test():
  rr = RefactorRecommender()
  rr.get_list_of_python_files('./src/funks')

  funk_module_names = [_.replace('/','.').replace('..','')[:-3] for _ in rr.python_files]
  funk_module_names.sort()


  durations = {}
  if exists('durations.pickle'):
    with open('durations.pickle', 'rb') as φ:
      durations = load(φ)

  durations_as_list = list(durations.items())
  
  sorted_funk_module_names = [
    'src.funks.'+_[0]
    for _
    in sorted(durations_as_list, key=lambda x: x[1])
  ]

  for funk_module_name in funk_module_names:
    if funk_module_name not in sorted_funk_module_names:
      sorted_funk_module_names.append(funk_module_name)

  max_filename_length = max([len(_) for _ in funk_module_names]) - 10

  print_header(max_filename_length)

  for funk_filename in sorted_funk_module_names:
    module = importlib.import_module(funk_filename)

    if not module.funk.test(max_filename_length):
      return False # Stop tests at first failure.
  return True # Reaching this point means all tests passed.

==> funki-0.0.120.tar.gz: funki-0.0.120/funki/test.py <==
from funki.refactor_recommender import RefactorRecommender
import importlib
from os.path import exists
from pickle import load
from os import listdir

def print_header(max_filename_length):
  name = "Name"
  duration_ms = "Duration [ms]"
  example_max_duration = "1024.567 █████████████████████"
  
  result ='\n'.join([
    f"| Result | {name:{max_filename_length}} | {duration_ms:^{len(example_max_duration)}}| ",
    f"|--------|-" + "-"*max_filename_length +"-|-" + "-"*len(example_max_duration)+"|"  
  ])
  print(result)

def test():
  rr = RefactorRecommender()
  rr.get_list_of_python_files('./src/funks')

  funk_module_names = [_.replace('/','.').replace('..','')[:-3] for _ in rr.python_files]
  funk_module_names.sort()


  durations = {}
  if exists('durations.pickle'):
    with open('durations.pickle', 'rb') as φ:
      durations = load(φ)

  durations_as_list = list(durations.items())
  
  sorted_funk_module_names = [
    'src.funks.'+_[0]
    for _
    in sorted(durations_as_list, key=lambda x: x[1])
  ]

  for funk_module_name in funk_module_names:
    if funk_module_name not in sorted_funk_module_names:
      sorted_funk_module_names.append(funk_module_name)

  max_filename_length = max([len(_) for _ in funk_module_names]) - 10

  print_header(max_filename_length)

  for funk_module_name in sorted_funk_module_names:
    if funk_module_name in funk_module_names:
      module = importlib.import_module(funk_module_name)

      if not module.funk.test(max_filename_length):
        return False # Stop tests at first failure.
  return True # Reaching this point means all tests passed.
